from pydantic import BaseModel, Field
from typing import List, Optional
from uuid import UUID
from datetime import datetime

class FruitBase(BaseModel):
    name: str = Field(..., min_length=1, description="Fruit name")

class FruitCreate(FruitBase):
    pass

class FruitUpdate(BaseModel):
    name: Optional[str] = Field(None, min_length=1, description="Fruit name")

class FruitSchema(FruitBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True
        schema_extra = {
            "example": {
                "id": "f47ac10b-58cc-4372-a567-0e02b2c3d479",
                "name": "Apple",
                "created_at": "2023-01-01T12:00:00",
                "updated_at": "2023-01-01T12:00:00"
            }
        }

class FruitsResponse(BaseModel):
    fruits: List[FruitSchema] = Field(..., description="List of fruit objects")

    class Config:
        schema_extra = {
            "example": {
                "fruits": [
                    {
                        "id": "f47ac10b-58cc-4372-a567-0e02b2c3d479",
                        "name": "Apple",
                        "created_at": "2023-01-01T12:00:00",
                        "updated_at": "2023-01-01T12:00:00"
                    }
                ]
            }
        }